/*
 * C
 *
 * Copyright 2012 IS2T. All rights reserved.
 * For demonstration purpose only.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

#include "cpu.h"
#if MCU == 2
#include "stm32f2xx.h"
#include "stm32f2xx_gpio.h"
#include "stm32f2xx_rcc.h"
#include "stm322xg_eval.h"
#elif MCU == 4
#include "stm32f4xx.h"
#include "stm32f4xx_gpio.h"
#include "stm32f4xx_rcc.h"
#include "stm324xg_eval.h"
#else
#error Invalid MCU
#endif

#define INVALID_ID	-1
#define OK	0

#define GPIO_COUNT 4

const uint16_t GPIO_ID[GPIO_COUNT] = { GPIO_Pin_6, GPIO_Pin_8, GPIO_Pin_9, GPIO_Pin_7 };
const GPIO_TypeDef* GPIO_PORT_ID[GPIO_COUNT] = { GPIOG, GPIOG, GPIOI, GPIOC };
const uint32_t GPIO_CLOCK_PORT_ID[GPIO_COUNT] = { RCC_AHB1Periph_GPIOG, RCC_AHB1Periph_GPIOG, RCC_AHB1Periph_GPIOI, RCC_AHB1Periph_GPIOC };

/**
 * @brief  To initialize the GPIOs in output PushPull.
 * @param  None
 * @retval None
 */
void Java_com_is2t_gpios_GPIOsNatives_initGPIOs(void) {
	GPIO_InitTypeDef GPIO_InitStructure;
	uint32_t i = 0;
	for (i = 0; i < GPIO_COUNT; i++)
	{
		/* Enable the BUTTON Clock */
		RCC_AHB1PeriphClockCmd(GPIO_CLOCK_PORT_ID[i], ENABLE);

		/* Configure Button pin as input */
		GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
		GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
		GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
		GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
		GPIO_InitStructure.GPIO_Pin = GPIO_ID[i];

		GPIO_Init((GPIO_TypeDef*) GPIO_PORT_ID[i], &GPIO_InitStructure);
	}
}

/**
 * @brief  To return the GPIO Output available
 * @param  None
 * @retval Output available
 */
int Java_com_is2t_gpios_GPIOsNatives_getGPIOsCount() {
	return GPIO_COUNT;
}

/**
 * @brief  To toggle output
 * @param  Output ID
 * @retval OK or invalid ID
 */
int Java_com_is2t_gpios_GPIOsNatives_toggleGPIO(int id) {
	if (id >=  GPIO_COUNT) return INVALID_ID;
	GPIO_ToggleBits((GPIO_TypeDef*) GPIO_PORT_ID[id], GPIO_ID[id]);
	return OK;
}
