/**
 * Java
 * Copyright 2012 IS2T. All rights reserved
 * For demonstration purpose only
 * IS2T PROPRIETARY / Use is subject to license terms.
 */
package com.is2t.gpios;

import ej.bon.Timer;
import ej.bon.TimerTask;

public class GPIOs {

	private static Timer timer = new Timer();
	private static boolean[] isBlinking = new boolean[getGPIOsCount()];
	static {
		GPIOsNatives.initGPIOs();
	}

	/**
	 * Gets the number of available GPIOs.
	 * 
	 * @return the number of GPIOs
	 */
	public static int getGPIOsCount() {
		return GPIOsNatives.getGPIOsCount();
	}

	/**
	 * Blinks a GPIO at fixed rate.
	 * 
	 * @param id
	 *            the index of the GPIO to blink
	 * @param delay
	 *            the delay between two toggles
	 * @throws IllegalArgumentException
	 *             if the given id is not valid or
	 *             if the GPIO is already blinking
	 */
	public static void blinkGPIO(final int id, long delay) throws IllegalArgumentException {
		if (id < 0 || id >= getGPIOsCount()) {
			throw new IllegalArgumentException();
		}
		if (isBlinking[id]) {
			throw new IllegalArgumentException();
		}
		isBlinking[id] = true;
		TimerTask task = new TimerTask() {

			public void run() {
				toggleGPIO(id);
			}
		};
		timer.scheduleAtFixedRate(task, 0, delay);
	}

	private static void toggleGPIO(int id) throws IllegalArgumentException {
		int resultOfToggleGPIO = GPIOsNatives.toggleGPIO(id);
		if (resultOfToggleGPIO == GPIOsNatives.INVALID_ID) {
			throw new IllegalArgumentException(id + " is invalid");
		}
	}
}
